@@ -39,6 +39,7 @@
 #include "yahoo-adapter.h"
 #include "yahoo-backend.h"
 #include <config.h>
+#include "compat.h"
 
 extern void ext_yahoo_got_buddies (int id, YList * buds);
 extern void ext_yahoo_got_ignore (int id, YList * igns);
@@ -175,7 +176,7 @@ get_current_status (void)
 }
 
 void
-set_current_status (int current_status_value)
+set_current_status (long current_status_value)
 {
   current_status = current_status_value;
 }
@@ -262,8 +263,8 @@ command_generator (const char *text, int state)
 {
   static int i, len;
   static int buddy_index, toggle_index;
-  static unsigned long dynamic_cmd_index;
-  unsigned long dynamic_commands_count;
+  static unsigned long dynamic_cmd_index = 0 ;
+  unsigned long dynamic_commands_count = 0;
   char *dynamic_command;
   char *name;
   yahoo_account *temp_buddy;
@@ -433,8 +434,9 @@ command_generator (const char *text, int state)
 	    dynamic_command = 
 	      scm_to_locale_string (scm_list_ref 
 				    (scm_list_ref (dynamic_commands, 
-						   scm_from_ulong (dynamic_cmd_index++)),
+						   scm_from_ulong (dynamic_cmd_index)),
 				     scm_from_ulong (0)));
+	    dynamic_cmd_index++;
 	    if (dynamic_command && strncasecmp (dynamic_command, text, len) == 0)
 	      return strdup (dynamic_command);
 	  }
