@@ -65,6 +65,7 @@
 #include "yahoo-adapter.h"
 #include "yahoo-utils.h"
 #include "extension.h"
+#include "compat.h"
 
 // static char *local_host = "127.0.0.1";
 static int do_mail_notify = 1;
@@ -1348,7 +1349,7 @@ void get_file_geturl_callback(int id, int fd, int error, const char * _fname, un
 
   sprintf(lfile, "%s/%s", get_downloads_directory (), filename);
 
-  lfd = open (lfile, O_CREAT | O_RDWR);
+  lfd = open (lfile, O_CREAT | O_RDWR, S_IRWXU);
   if (lfd < 0)
     {
       PRINTF_MESSAGE ("Error in opening file [%s]\n", lfile) ;
